@@ -7,9 +7,9 @@ use warnings;
 use Role::Tiny::With;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-09-26'; # DATE
+our $DATE = '2021-09-28'; # DATE
 our $DIST = 'TableDataRoles-Standard'; # DIST
-our $VERSION = '0.010'; # VERSION
+our $VERSION = '0.011'; # VERSION
 
 with 'TableDataRole::Source::AOH';
 
@@ -28,13 +28,13 @@ TableData::AOH - Get table data from array of hashes
 
 =head1 VERSION
 
-This document describes version 0.010 of TableData::AOH (from Perl distribution TableDataRoles-Standard), released on 2021-09-26.
+This document describes version 0.011 of TableData::AOH (from Perl distribution TableDataRoles-Standard), released on 2021-09-28.
 
 =head1 SYNOPSIS
 
  use TableData::AOH;
 
- my $table = TableData::DBI->new(
+ my $table = TableData::AOH->new(
      aoh => [{col1=>1,col2=>2}, {col1=>3,col2=>4}],
  );
 
@@ -52,6 +52,8 @@ Source repository is at L<https://github.com/perlancar/perl-TableDataRoles-Stand
 
 =head1 SEE ALSO
 
+L<TableData::AOA>
+
 L<TableData>
 
 =head1 AUTHOR
