@@ -7,9 +7,9 @@ use warnings;
 use Role::Tiny;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-09-26'; # DATE
+our $DATE = '2021-09-28'; # DATE
 our $DIST = 'TableDataRoles-Standard'; # DIST
-our $VERSION = '0.010'; # VERSION
+our $VERSION = '0.011'; # VERSION
 
 with 'TableDataRole::Spec::Basic';
 
@@ -89,7 +89,6 @@ sub get_row_count {
 
 sub reset_iterator {
     my $self = shift;
-    delete $self->{buffer};
     $self->{pos} = 0;
 }
 
@@ -113,7 +112,7 @@ TableDataRole::Source::AOH - Get table data from an array of hashes
 
 =head1 VERSION
 
-This document describes version 0.010 of TableDataRole::Source::AOH (from Perl distribution TableDataRoles-Standard), released on 2021-09-26.
+This document describes version 0.011 of TableDataRole::Source::AOH (from Perl distribution TableDataRoles-Standard), released on 2021-09-28.
 
 =head1 SYNOPSIS
 
@@ -139,6 +138,8 @@ Source repository is at L<https://github.com/perlancar/perl-TableDataRoles-Stand
 
 =head1 SEE ALSO
 
+L<TableDataRole::Source::AOA>
+
 L<TableData>
 
 =head1 AUTHOR
